indexing

	description: "getest based test for writing XML messages."

	author: "Berend de Boer"
	date: "$Date: 2004/12/18 $"
	revision: "$Revision: #3 $"


deferred class

	TEST_XML_WRITER

inherit

	TS_TEST_CASE

feature -- Tests

	test_attributes is
		local
			xml: EPX_XML_WRITER
		do
			create xml.make_fragment
			xml.start_tag ("a")
			xml.set_attribute ("b", Void)
			xml.set_attribute ("c", "")
			xml.set_attribute ("d", "a")
			xml.stop_tag
			debug ("test")
				print (xml.as_string)
			end
		end

	test_escape is
		local
			xml: EPX_XML_WRITER
		do
			create xml.make_fragment
			xml.start_tag ("a")
			xml.add_data ("this & that")
			xml.stop_tag
			assert_equal ("Escaped content treated correctly.", "<a>this &amp; that</a>%N", xml.as_string)

			xml.clear
			xml.start_tag ("a")
			xml.add_data ("test>")
			xml.stop_tag
			assert_equal ("Escaped content treated correctly.", "<a>test></a>%N", xml.as_string)

			xml.clear
			xml.start_tag ("a")
			xml.add_data ("test]]>")
			xml.stop_tag
			assert_equal ("Escaped content treated correctly.", "<a>test]]&gt;</a>%N", xml.as_string)

			xml.clear
			xml.start_tag ("a")
			xml.add_data ("test]>")
			xml.stop_tag
			assert_equal ("Escaped content treated correctly.", "<a>test]></a>%N", xml.as_string)

			xml.clear
			xml.start_tag ("a")
			xml.add_data ("]>")
			xml.stop_tag
			assert_equal ("Escaped content treated correctly.", "<a>]></a>%N", xml.as_string)

			xml.clear
			xml.start_tag ("a")
			xml.add_data ("]]>")
			xml.stop_tag
			assert_equal ("Escaped content treated correctly.", "<a>]]&gt;</a>%N", xml.as_string)

			xml.clear
			xml.start_tag ("a")
			xml.add_data ("]]>ab")
			xml.stop_tag
			assert_equal ("Escaped content treated correctly.", "<a>]]&gt;ab</a>%N", xml.as_string)
		end

	test_cdata is
		local
			xml: EPX_XML_WRITER
		do
			create xml.make_fragment
			xml.start_tag ("a")
			xml.add_cdata ("hello")
			xml.stop_tag
			assert_equal ("CDATA added", "<a><![CDATA[hello]]></a>%N", xml.as_string)

			create xml.make_fragment
			xml.start_tag ("a")
			xml.add_cdata ("hel]]>lo")
			xml.stop_tag
			assert_equal ("CDATA escape works", "<a><![CDATA[hel]]>]]&gt;<![CDATA[lo]]></a>%N", xml.as_string)

			create xml.make_fragment
			xml.start_tag ("a")
			xml.add_cdata ("hel]]>]]>lo")
			xml.stop_tag
			assert_equal ("CDATA really works", "<a><![CDATA[hel]]>]]&gt;<![CDATA[]]>]]&gt;<![CDATA[lo]]></a>%N", xml.as_string)

		end

	test_incremental is
		local
			xml: EPX_INCREMENTAL_XML_WRITER
		do
			create xml.make_fragment
			xml.start_tag ("a")
			xml.start_tag ("b")
			xml.incremental_write
			debug ("test")
				print ("XML:%N")
				print (xml.last_string)
				print ("%N")
			end
			xml.set_attribute ("c", "")
			xml.set_attribute ("d", "a")
			xml.incremental_write
			debug ("test")
				print ("XML:%N")
				print (xml.last_string)
				print ("%N")
			end
			xml.stop_tag
			xml.incremental_write
			debug ("test")
				print ("XML:%N")
				print (xml.last_string)
				print ("%N")
			end
			xml.stop_tag
			xml.incremental_write
			debug ("test")
				print ("XML:%N")
				print (xml.last_string)
				print ("%N")
			end
		end

end
